@@ -12,10 +12,10 @@
 # implied. See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Default allowed headers
 import copy
 import logging
 
+import debtcollector
 from oslo_config import cfg
 from oslo_middleware import base
 import six
@@ -198,6 +198,11 @@ class CORS(base.ConfigurableMiddleware):
         # prefixed with 'cors.'
         for section in self.oslo_conf.list_all_sections():
             if section.startswith('cors.'):
+                debtcollector.deprecate('Multiple configuration blocks are '
+                                        'deprecated and will be removed in '
+                                        'future versions. Please consolidate '
+                                        'your configuration in the [cors] '
+                                        'configuration block.')
                 # Register with the preconstructed defaults
                 self.oslo_conf.register_opts(subgroup_opts, section)
                 self.add_origin(**self.oslo_conf[section])
@@ -219,6 +224,9 @@ class CORS(base.ConfigurableMiddleware):
         # NOTE(dims): Support older code that still passes in
         # a string for allowed_origin instead of a list
         if isinstance(allowed_origin, six.string_types):
+            # TODO(krotscheck): https://review.openstack.org/#/c/312687/
+            LOG.warning('DEPRECATED: The `allowed_origin` keyword argument in '
+                        '`add_origin()` should be a list, found String.')
             allowed_origin = [allowed_origin]
 
         if allowed_origin:
